#!/usr/bin/env python3
# encoding=utf-8

"""
Convert a document to a PDF

Run with a command like
    scribus -g -py export_to_pdf.py -version 13 -useDocBleeds 0 -bleedr 2 -compress 1 -info 'test title' -file 'test.pdf' -pages '[1, 2]' -- testdoc.sla

You can set any "pdf" attribute with "-attribute value".

Tested with scribus 1.5.2.svn r21147

Author: William Bader, Director of Research and Development, SCS, http://www.newspapersystems.com
15Sep15 wb              initial version
31Mar16 Jural Fedel     simplified, added support for page ranges
31Mar16 Andres Gomez    replaced 8 spaces indent with 4 spaces.

"""

import scribus
import sys
import ast

def main(argv):
    pdf = scribus.PDFfile()
    i = 1
    while i < len(argv):
        if (argv[i][0] != '-'):
            raise Exception("PDF option expected instead of: '{0}'".format(argv[i]))
        name = argv[i][1:]
        pdf_attr = getattr(pdf, name)
        i = i + 1
        try:
            value = argv[i]
        except:
            msg = "Option '{0}' require value".format(name)
            raise Exception(msg)
        if isinstance(pdf_attr, str):
            setattr(pdf, name, value)
        else:
            val = None
            try:
                val = ast.literal_eval(value)
            except:
                msg = "'{0}' =/= '{1}'".format(name, value)
                raise ValueError(msg)
            setattr(pdf, name, val)
        i = i + 1
    pdf.save()

# start the script
if __name__ == '__main__':
    main(sys.argv)
